[Spread-cvs] commit: r263 - trunk/stdutil/src

jschultz at spread.org jschultz at spread.org
Mon Aug 8 17:21:14 EDT 2005


Author: jschultz
Date: 2005-08-08 17:21:13 -0400 (Mon, 08 Aug 2005)
New Revision: 263

Modified:
   trunk/stdutil/src/stdthread.c
Log:
Updates to init/fini again.



Modified: trunk/stdutil/src/stdthread.c
===================================================================
--- trunk/stdutil/src/stdthread.c	2005-08-08 04:53:24 UTC (rev 262)
+++ trunk/stdutil/src/stdthread.c	2005-08-08 21:21:13 UTC (rev 263)
@@ -841,10 +841,10 @@
 #  endif
 
 /************************************************************************************************
- * stdmutex_init: Initialize a mutex.
+ * stdmutex_construct: Initialize a mutex.
  ***********************************************************************************************/
 
-STDINLINE stdcode stdmutex_init(stdmutex *mut, stdmutex_type t)
+STDINLINE stdcode stdmutex_construct(stdmutex *mut, stdmutex_type t)
 {
   stdcode ret = STDEINVAL;
 
@@ -862,10 +862,10 @@
 }
 
 /************************************************************************************************
  * stdmutex_fini: Invalidate a mutex and reclaim its resources.
  ***********************************************************************************************/
 
-STDINLINE stdcode stdmutex_fini(stdmutex *mut) 
+STDINLINE stdcode stdmutex_destruct(stdmutex *mut) 
 {
   stdcode ret = STDEINVAL;
 
@@ -967,10 +967,10 @@
 }
 
 /************************************************************************************************
  * stdcond_init: Initialize a condition variable.
  ***********************************************************************************************/
 
-STDINLINE stdcode stdcond_init(stdcond *cond)
+STDINLINE stdcode stdcond_construct(stdcond *cond)
 #  if defined(_WIN32)
 {
   stdcode ret;
@@ -993,10 +993,10 @@
 #  endif
 
 /************************************************************************************************
  * stdcond_fini: Invalidate a condition variable and reclaim its resources.
  ***********************************************************************************************/
 
-STDINLINE stdcode stdcond_fini(stdcond *cond)
+STDINLINE stdcode stdcond_destruct(stdcond *cond)
 #  if defined(_WIN32)
 {
   stdcode ret;
@@ -862,10 +862,10 @@
 
 /************************************************************************************************
- * stdmutex_fini: Invalidate a mutex and reclaim its resources.
+ * stdmutex_destruct: Invalidate a mutex and reclaim its resources.
  ***********************************************************************************************/
 
@@ -967,10 +967,10 @@
 
 /************************************************************************************************
- * stdcond_init: Initialize a condition variable.
+ * stdcond_construct: Initialize a condition variable.
  ***********************************************************************************************/
 
@@ -993,10 +993,10 @@
 
 /************************************************************************************************
- * stdcond_fini: Invalidate a condition variable and reclaim its resources.
+ * stdcond_destruct: Invalidate a condition variable and reclaim its resources.
  ***********************************************************************************************/
 




More information about the Spread-cvs mailing list